@@ -1,7 +1,7 @@
 =begin
     mo.rb - A simple class for operating GNU MO file.
 
-    Copyright (C) 2003,2004  Masao Mutoh
+    Copyright (C) 2003-2005  Masao Mutoh
     Copyright (C) 2002  Masahiro Sakai, Masao Mutoh
     Copyright (C) 2001  Masahiro Sakai
 
@@ -12,7 +12,7 @@
     of Ruby.  License of Ruby is included with Ruby distribution in
     the file "README".
 
-    $Id: mo.rb,v 1.8 2004/10/21 16:19:30 mutoh Exp $
+    $Id: mo.rb,v 1.2 2005/10/22 10:49:59 mutoh Exp $
 =end
 
 require 'gettext/iconv'
@@ -102,10 +102,10 @@ class MOFile < Hash
             str = Iconv.iconv(@output_charset, @charset, str).join if @charset
           rescue Iconv::Failure
             if $DEBUG
-              print "@charset = ", @charset, "\n"
-              print "@output_charset = ", @output_charset, "\n"
-              print "msgid = ", original_strings[i], "\n"
-              print "msgstr = ", str, "\n"
+              $stderr.print "@charset = ", @charset, "\n"
+              $stderr.print "@output_charset = ", @output_charset, "\n"
+              $stderr.print "msgid = ", original_strings[i], "\n"
+              $stderr.print "msgstr = ", str, "\n"
             end
           end
         end
@@ -233,6 +233,11 @@ class MOFile < Hash
     File.open(filename, 'wb'){|f| save_to_stream(f)}
   end
 
+  def set_comment(msgid_or_sym, comment)
+    #Do nothing
+  end
+
+
   attr_accessor :little_endian
   attr_reader :charset, :nplurals, :plural
 end
