@@ -1,32 +1,33 @@
 =begin
   parser/glade.rb - parser for Glade-2
 
-  Copyright (C) 2004  Masao Mutoh
+  Copyright (C) 2004,2005  Masao Mutoh
  
   You may redistribute it and/or modify it under the same
   license terms as Ruby.
+
+  $Id: glade.rb,v 1.2 2005/12/17 07:12:40 mutoh Exp $
 =end
 
 require 'cgi'
+require 'gettext'
 
 module GetText
   module GladeParser
+    extend GetText
+    bindtextdomain("rgettext")
 
     TARGET1 = /<property.*translatable="yes">(.*)/
     TARGET2 = /(.*)<\/property>/
 
     module_function
-    def parse(files, targets = [])
-      @targets = targets
-      files.each do |file|
-        lines = IO.readlines(file)
-        parse_lines(file, lines)
-      end
-      @targets
+    def parse(file, targets = [])
+      lines = IO.readlines(file)
+      parse_lines(file, lines, targets)
     end
 
     #from ary of lines.
-    def parse_lines(file, lines)
+    def parse_lines(file, lines, targets)
       cnt = 0
       target = false
       line_no = 0
@@ -43,14 +44,14 @@ module GetText
           target = true
           if TARGET2 =~ $1
             val = $1
-            add_target(val, file, line_no)
+            add_target(val, file, line_no, targets)
             val = nil
             target = false
           end
         elsif target
           if TARGET2 =~ line
             val << $1
-            add_target(val, file, line_no)
+            add_target(val, file, line_no, targets)
             val = nil
             target = false
           else
@@ -58,22 +59,42 @@ module GetText
           end
         end
       end
+      targets
     end
 
-    def add_target(val, file, line_no)
+    XML_RE = /<\?xml/ 
+    GLADE_RE = /glade-2.0.dtd/
+ 
+    def target?(file)
+      data = IO.readlines(file)
+      if XML_RE =~ data[0]
+	if GLADE_RE =~ data[1]
+	  return true
+	else
+	  raise _("%s is not glade-2.0 format.") % [file]
+	end
+      else
+	return false
+      end
+    end
+
+    def add_target(val, file, line_no, targets)
       return unless val.size > 0
-      assoc_data = @targets.assoc(val)
+      assoc_data = targets.assoc(val)
       val = CGI.unescapeHTML(val)
       if assoc_data 
-        @targets[@targets.index(assoc_data)] = assoc_data << "#{file}:#{line_no}"
+        targets[targets.index(assoc_data)] = assoc_data << "#{file}:#{line_no}"
       else
-        @targets << [val.gsub(/\n/, '\n'), "#{file}:#{line_no}"]
+        targets << [val.gsub(/\n/, '\n'), "#{file}:#{line_no}"]
       end
+      targets
     end
   end
 end
 
 if __FILE__ == $0
   # ex) ruby glade.rb foo.glade  bar.glade
-  p GetText::GladeParser.parse(ARGV)
+  ARGV.each do |file|
+    p GetText::GladeParser.parse(file)
+  end
 end
