@@ -2,41 +2,28 @@
 =begin
   parser/ruby.rb - parser for ruby script
 
-  Copyright (C) 2003,2004  Masao Mutoh
+  Copyright (C) 2003-2005  Masao Mutoh
+  Copyright (C) 2005       speakillof
   Copyright (C) 2001,2002  Yasushi Shoji, Masao Mutoh
  
-      Yasushi Shoji   <yashi@yashi.com>
-      Masao Mutoh     <mutoh@highway.ne.jp>
- 
   You may redistribute it and/or modify it under the same
   license terms as Ruby.
+
+  $Id: ruby.rb,v 1.4 2005/12/17 07:12:40 mutoh Exp $
 =end
 
-require 'irb/ruby-lex'
-require 'irb/ruby-token'
+require 'irb/ruby-lex.rb'
+require 'stringio'
 
 class RubyLexX < RubyLex
+  
   def initialize
     super
     @prompt = nil
     @here_header = nil
     @lex_state = nil
   end
-
-  def token
-    tk = super
-    if $DEBUG
-      if tk.is_a? TkSTRING
-        $stderr.puts("#{tk}: #{tk.value}")
-      elsif tk.is_a? TkIDENTIFIER
-        $stderr.puts("#{tk}: #{tk.name}")
-      else
-        $stderr.puts(tk)
-      end
-    end
-    tk
-  end
-
+  
   def read_escape
     case ch = getc
     when "\n", "\r", "\f"
@@ -88,45 +75,51 @@ class RubyLexX < RubyLex
       # other characters
     end
   end
-  
-  def identify_string(ltype, quoted = ltype)
-    @ltype = ltype
-    @quoted = quoted
-    subtype = nil
-    str = ''
-    begin
-      while ch = getc
-        if @quoted == ch
-      break
-        elsif @ltype != "'" && @ltype != "]" and ch == "#"
-          subtype = true
-        elsif ch == '\\' #'
-          e = read_escape
-          str.concat e unless e.nil?
+
+  # Parser#parse resemlbes RubyLex#lex
+  def parse
+    until (  (tk = token).kind_of?(RubyToken::TkEND_OF_SCRIPT) && !@continue or tk.nil?  )
+      s = get_readed
+ 
+      if RubyToken::TkSTRING === tk
+        def tk.value
+          @value 
+        end
+        
+        def tk.value=(s)
+          @value = s
+        end
+        
+        if @here_header
+          s = s.sub(/\A.*?\n/, '').sub(/^.*\n\Z/, '')
         else
-          str.concat ch
+	  begin
+	    s = eval(s)
+	  rescue Exception
+	    # Do nothing.
+	  end
+        end
+        
+        tk.value = s
+      end
+      
+      if $DEBUG
+        if tk.is_a? TkSTRING
+          $stderr.puts("#{tk}: #{tk.value}")
+        elsif tk.is_a? TkIDENTIFIER
+          $stderr.puts("#{tk}: #{tk.name}")
+        else
+          $stderr.puts(tk)
         end
       end
-      if @ltype == "/"
-    if peek(0) =~ /i|o|n|e|s/
-      getc
-    end
-      end
-      if subtype
-        tk = Token(DLtype2Token[ltype], str)
-      else
-        tk = Token(Ltype2Token[ltype], str)
-      end
-    ensure
-      @ltype = nil
-      @quoted = nil
-      @lex_state = EXPR_END
+      
+      yield tk
     end
+    
+    return nil
   end
-end
 
-######################################################################
-# GetText::RubyParser
+end
 
 module GetText
   module RubyParser
@@ -134,26 +127,23 @@ module GetText
     PLURAL_ID = ['ngettext', 'n_']
 
     module_function
-    def parse(files, targets = [])
-      @targets = targets
-      files.each do |file|
-        lines = IO.readlines(file)
-        parse_lines(file, lines)
-      end
-      @targets
+    def parse(file, targets = [])
+      lines = IO.readlines(file)
+      parse_lines(file, lines, targets)
     end
-    
-    def parse_lines(file_name, lines)
-      file = File.new(file_name)
+
+    def parse_lines(file_name, lines, targets)
+      file = StringIO.new(lines.join + "\n")
       rl = RubyLexX.new
       rl.set_input(file)
       rl.skip_space = true
-      rl.readed_auto_clean_up = true
+      #rl.readed_auto_clean_up = true
 
       target = nil
       msgid = nil
       line_no = nil
-      while tk = rl.token
+      
+      rl.parse do |tk|
         case tk
         when RubyToken::TkIDENTIFIER, RubyToken::TkCONSTANT
           if ID.include?(tk.name)
@@ -181,24 +171,40 @@ module GetText
           end
         else
           if msgid
-            key_existed = @targets.assoc(msgid)
+            key_existed = targets.assoc(msgid)
             if key_existed 
-              @targets[@targets.index(key_existed)] = key_existed <<
+              targets[targets.index(key_existed)] = key_existed <<
                 file_name + ":" + line_no
             else
-              @targets << [msgid.gsub(/\n/, '\n'), file_name + ":" + line_no]
+              targets << [msgid.gsub(/\n/, '\n'), file_name + ":" + line_no]
             end
             msgid = nil
             target = nil
           end
         end
-        @targets
+        targets
       end
+      
+      targets
     end
+
+    def target?(file)
+      true # always true, as default parser.
+    end
+    
   end 
-end  
+end
+
+
 
 if __FILE__ == $0
-  # ex) ruby c.rb foo.c bar.c
-  p GetText::RubyParser.parse(ARGV)
+  require 'pp'
+  ARGV.each do |file|
+    pp GetText::RubyParser.parse(file)
+  end
+  
+  #rl = RubyLexX.new; rl.set_input(ARGF)  
+  #rl.parse do |tk|
+    #p tk
+  #end  
 end
