@@ -1,14 +1,20 @@
 require 'test/unit/testsuite'
 require 'gettext_test'
 require 'gettext_test_parser'
+require 'gettext_test_string'
 
 class GetTextTest
    def suite
      s = Test::Unit::TestSuite.new
      s << TestGetText.suite
      s << TestGetTextParser.suite
+     s << TestGetTextString.suite
      s
    end
 end
 
-Test::Unit::AutoRunner.run
+if RUBY_VERSION >= '1.8.4'
+  Test::Unit::AutoRunner.run
+else
+  Test::Unit::AutoRunner.run(GetTextTest)
+end
