@@ -1,7 +1,7 @@
 require 'gettext'
 include GetText
 
-class TestLib4
+class TestRubyParser
   bindtextdomain("test_rubyparser", "locale", "ja")
 
   def test_1
@@ -73,5 +73,25 @@ ddd
   def test_16
     _('\taaa')
   end
+
+  def test_17
+    ret = _(<<EOF
+Here document1
+Here document2
+EOF
+)
+  end
+
+
 end
     
+  def test_17
+    a = []
+    a << 1
+    a << "2"
+    ret = _(<<EOF
+Here document1
+Here document2
+EOF
+)
+  end
